// Copyright (C) 2018 Avatao.com Innovative Learning Kft.
// All Rights Reserved. See LICENSE file for details.

import { Injectable } from '@angular/core';
import { WebSocketService } from './websocket.service';
import { LogMessage } from '../message-types/log-message';
import { ProcessLogCommand } from '../message-types/process-log-command';
import { config } from '../config';
import { BehaviorSubject } from 'rxjs';

@Injectable()
export class ProcessLogService {
  newLogs = new BehaviorSubject<LogMessage>(config.console.defaultLogs);
  showLiveLogs = config.console.showLiveLogs;

  constructor(private webSocketService: WebSocketService) {
    this.webSocketService.connect();
    this.webSocketService.observeKey<ProcessLogCommand>('log.new').subscribe(
      (event) => this.newLogsHandler(event)
    );
  }

  emitNewLogsIfNoLiveLogs(logs: LogMessage) {
    if (!this.showLiveLogs) {
      this.newLogs.next(logs);
    }
  }

  newLogsHandler(data: ProcessLogCommand) {
    if (this.showLiveLogs) {
      this.newLogs.next({
        stdout: data.stdout,
        stderr: data.stderr
      });
    }
  }
}
